@@ -311,7 +311,7 @@ Ods2Csv::run()
         }
 
       OdsDocReader reader(handler);
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+      qDebug();
 
       if(ods_file.isEmpty())
         {
@@ -319,7 +319,10 @@ Ods2Csv::run()
           // zip file can not be parsed as stream :
           // we need to read all data before reading content
           QFile input_stream;
-          input_stream.open(stdin, QIODevice::ReadOnly);
+          if(!input_stream.open(stdin, QIODevice::ReadOnly))
+            {
+              throw OdsException(QObject::tr("unable to read stdin"));
+            }
           QByteArray data(input_stream.readAll());
           input_stream.close();
 
@@ -328,14 +331,17 @@ Ods2Csv::run()
         }
       else
         {
-          qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+          qDebug();
           QFile file(ods_file);
           reader.parse(file);
+          qDebug();
         }
     }
   catch(OdsException &error)
     {
-      errorStream << "Oops! an error occurred in Ods2Csv. Don't Panic :" << endl;
+      qDebug();
+      errorStream << "Oops! an error occurred in Ods2Csv. Don't Panic :"
+                  << endl;
       errorStream << error.qwhat() << endl;
       exit(1);
       app->exit(1);
@@ -343,7 +349,9 @@ Ods2Csv::run()
 
   catch(std::exception &error)
     {
-      errorStream << "Oops! an error occurred in Ods2Csv. Don't Panic :" << endl;
+      qDebug();
+      errorStream << "Oops! an error occurred in Ods2Csv. Don't Panic :"
+                  << endl;
       errorStream << error.what() << endl;
       exit(1);
       app->exit(1);
@@ -379,6 +387,7 @@ Ods2Csv::aboutToQuitApp()
 int
 main(int argc, char **argv)
 {
+  qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
   // QTextStream consoleErr(stderr);
   // QTextStream consoleOut(stdout, QIODevice::WriteOnly);
   // ConsoleOut::setCout(new QTextStream(stdout, QIODevice::WriteOnly));
