@@ -17,8 +17,7 @@
 
 */
 
-#ifndef SAXHANDLERCONTENTXML_H
-#define SAXHANDLERCONTENTXML_H
+#pragma once
 
 #include <QXmlDefaultHandler>
 #include <QString>
@@ -76,5 +75,3 @@ class SaxHandlerContentXml : public QXmlDefaultHandler
 
   bool _is_annotation = false;
 };
-
-#endif // SAXHANDLERCONTENTXML_H
